@@ -1,6 +1,10 @@
+import logging
+
 import numpy as np
 from PIL import Image
 
+logger = logging.getLogger(__name__)
+
 
 class ModelNotImplementedError(Exception):
     pass
@@ -18,7 +22,8 @@ def open_img(image: object) -> Image:
     elif isinstance(image, np.ndarray):
         to_predict = Image.fromarray(np.uint8(image))
     else:
-        raise ValueError(str(type(image)) + " not implemented")
+        logging.warning(str(type(image)) + " not implemented, attempt to load with PIL")
+        to_predict = Image.open(image)
     to_predict = to_predict.convert("RGB")
 
     return to_predict
